#!/bin/bash

# create function to try to copy file if does not exits
copy_from_cicd_variables()
{
    # if no file name is provided, return
    var_name=$1
    if [[ -z "$var_name" ]]
    then
        return
    fi

    file_path=$2
    if [[ -z "$file_path" ]]
    then
        return
    fi

    # if file does not exist, try to copy from CI/CD variables
    if [[ ! -f "$file_path" ]]
    then
        log_info "--- \\e[33m$file_path\\e[0m does not exist, trying to copy from CI/CD variables"
        # get value from a variable with the same name as the file
        source_file_path=$(eval echo "\$$var_name")
        if [[ -n "$source_file_path" ]]
        then
            log_info "--- \\e[32m$var_name\\e[0m found in CI/CD variables"
            if [[ -f "$source_file_path" ]]
            then
                mkdir -p $(dirname "$file_path") || true
                cp -f "$source_file_path" "$file_path"
                log_info "--- \\e[32m$var_name\\e[0m copied from CI/CD variables"
            else
                log_info "--- \\e[31m$source_file_path\\e[0m not found in CI/CD variables"
            fi
        else
            log_info "--- \\e[31m$var_name\\e[0m not found in CI/CD variables"
        fi
    fi
}

log_info()
{
    echo -e "\\e[32mINFO: $1\\e[0m"
}

copy_from_cicd_variables "dockerconfigjson" "components/artifactory-secrets/.secrets/dockerconfigjson"
copy_from_cicd_variables "keycloak_secrets" "components/keycloak-secrets/.secrets/keycloak"
copy_from_cicd_variables "rcm_backend_secrets" "components/rcm/.secrets/rcm_backend"
copy_from_cicd_variables "rcm_frontend_secrets" "components/rcm/.secrets/rcm_frontend"
copy_from_cicd_variables "rcm_converter_secrets" "components/rcm/.secrets/rcm_converter"
copy_from_cicd_variables "rcm_mariadb_secrets" "components/rcm/.secrets/rcm_mariadb"
copy_from_cicd_variables "amoe_mongodb_secrets" "components/amoe/.secrets/amoe_mongodb"
copy_from_cicd_variables "amoe_redis_secrets" "components/amoe/.secrets/amoe_redis"
copy_from_cicd_variables "amoe_secrets" "components/amoe/.secrets/amoe"
copy_from_cicd_variables "orchestrator_secrets" "components/orchestrator/.secrets/orchestrator"
copy_from_cicd_variables "orchestrator_postgres_secrets" "components/orchestrator/.secrets/orchestrator_postgres"
copy_from_cicd_variables "orchestrator_postgres_setup_secrets" "components/orchestrator/.secrets/orchestrator_postgres_setup"
copy_from_cicd_variables "assessment_secrets" "components/assessment/.secrets/assessment"
copy_from_cicd_variables "emerald_ui_secrets" "components/emerald-ui/.secrets/emerald_ui"
copy_from_cicd_variables "clouditor_discovery_secrets" "components/clouditor-discovery/.secrets/clouditor_discovery"
copy_from_cicd_variables "evaluation_secrets" "components/evaluation/.secrets/evaluation"
copy_from_cicd_variables "evidence_store_secrets" "components/evidence-store/.secrets/evidence_store"
copy_from_cicd_variables "mari_secrets" "components/mari/.secrets/mari"
